@@ -39,9 +39,6 @@ from pysnmp.error import PySnmpError
 import asyncio
 
 
-IS_PYTHON_344_PLUS = tuple(int(version) for version in platform.python_version_tuple()) >= (3, 4, 4)
-
-
 class AsyncioDispatcher(AbstractTransportDispatcher):
     """AsyncioDispatcher based on asyncio event loop"""
 
@@ -70,11 +67,7 @@ class AsyncioDispatcher(AbstractTransportDispatcher):
     
     def registerTransport(self, tDomain, transport):
         if self.loopingcall is None and self.getTimerResolution() > 0:
-            # Avoid deprecation warning for asyncio.async()
-            if IS_PYTHON_344_PLUS:
-              self.loopingcall = asyncio.ensure_future(self.handle_timeout())
-            else: # pragma: no cover
-              self.loopingcall = getattr(asyncio, 'async')(self.handle_timeout())
+            self.loopingcall = asyncio.ensure_future(self.handle_timeout())
         AbstractTransportDispatcher.registerTransport(
             self, tDomain, transport
         )
